@@ -6,7 +6,14 @@ var classQore_1_1SSH2_1_1SSH2Base =
     [ "connected", "classQore_1_1SSH2_1_1SSH2Base.html#a829f2dcc70d888ef25550c28f830b7f3", null ],
     [ "constructor", "classQore_1_1SSH2_1_1SSH2Base.html#a1c7c23112d00c4932adf2235f87eaf28", null ],
     [ "disconnect", "classQore_1_1SSH2_1_1SSH2Base.html#a76365660f99862c84cce8ea6c0c38bdd", null ],
-    [ "getUsageInfo", "classQore_1_1SSH2_1_1SSH2Base.html#a0ec8e9522de48f70d4f79e0db6d71997", null ],
+    [ "getAuthenticatedWith", "classQore_1_1SSH2_1_1SSH2Base.html#aa2121e0ad963ffde343a91e11cc3adbb", null ],
+    [ "getHost", "classQore_1_1SSH2_1_1SSH2Base.html#a2551f5a73a07c41f2ced6dec929128e2", null ],
+    [ "getKeyPriv", "classQore_1_1SSH2_1_1SSH2Base.html#a08edebb29568fd69119b0800d9eb0da5", null ],
+    [ "getKeyPub", "classQore_1_1SSH2_1_1SSH2Base.html#a151b5ccd73daad0533036c4f28a3e6e5", null ],
+    [ "getPassword", "classQore_1_1SSH2_1_1SSH2Base.html#aeafd44274bd604c4f4f91e0b6de103fd", null ],
+    [ "getPort", "classQore_1_1SSH2_1_1SSH2Base.html#a8d1a030cbd248068b1a7e68d49fbae1a", null ],
+    [ "getUsageInfo", "classQore_1_1SSH2_1_1SSH2Base.html#a7ebbae66e5dbb6c50e1d78cf9d7f3bb5", null ],
+    [ "getUser", "classQore_1_1SSH2_1_1SSH2Base.html#a48940d71acdab9f641b22af994f8f7d1", null ],
     [ "setKeys", "classQore_1_1SSH2_1_1SSH2Base.html#aeeddcf778158affb5902fa0f92579f55", null ],
     [ "setPassword", "classQore_1_1SSH2_1_1SSH2Base.html#a0b9dec26b401e77a9ec569653653d1aa", null ],
     [ "setUser", "classQore_1_1SSH2_1_1SSH2Base.html#a2e144927b3312143bd4d972b7a27a213", null ],
