@@ -1,10 +1,11 @@
 var indexSectionsWithContent =
 {
-  0: "cdegilmopqrstw",
+  0: "acdefgiklmnopqrstuw",
   1: "s",
   2: "q",
   3: "cdegilmoprstw",
-  4: "q"
+  4: "acdfgklmnpstu",
+  5: "q"
 };
 
 var indexSectionNames =
@@ -13,7 +14,8 @@ var indexSectionNames =
   1: "classes",
   2: "namespaces",
   3: "functions",
-  4: "pages"
+  4: "variables",
+  5: "pages"
 };
 
 var indexSectionLabels =
@@ -22,6 +24,7 @@ var indexSectionLabels =
   1: "Classes",
   2: "Namespaces",
   3: "Functions",
-  4: "Pages"
+  4: "Variables",
+  5: "Pages"
 };
 
